@@ -279,7 +279,12 @@ class Accessory(models.Model):
 
     @property
     def datatransformer(self):
-        return self.datatransformer_set.first().get_root()
+        try:
+            return self.datatransformer_set.first().get_root()
+        except:
+            print('datatransformer error sorta')
+        return self.datatransformer_set.first()
+
 
     class Meta:
         indexes = [
