@@ -31,17 +31,30 @@ class CalibrationSerializer(serializers.ModelSerializer):
 
 class ChannelStatsSerializer(serializers.ModelSerializer):
     channel = serializers.PrimaryKeyRelatedField(read_only=True)
+    model = serializers.SerializerMethodField()
 
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
     class Meta:
         model = CalibrationConstants
-        fields = ['channel', 'type', 'value']
+        fields = ['channel', 'type', 'value','model']
 
 class ChannelSerializer(serializers.ModelSerializer):
     channelstats = ChannelStatsSerializer(read_only=True,many=True)
+    model = serializers.SerializerMethodField()
+
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
 
     class Meta:
         model = Channel
-        fields = ['id', 'type', 'channel_index', 'hardware','channelstats']
+        fields = ['id', 'type', 'channel_index', 'hardware','channelstats','model']
 
 
 
@@ -49,6 +62,13 @@ class ChannelSerializer(serializers.ModelSerializer):
 
 class DataTransformerSerializer(serializers.ModelSerializer):
     data_transformer_child = RecursiveField(many=True)
+    model = serializers.SerializerMethodField()
+
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
 
     class Meta:
         model = DataTransformer
@@ -92,6 +112,13 @@ class VEML7700Serializer(serializers.ModelSerializer):
 
 
 class HardwareSerializer(serializers.ModelSerializer):
+    model = serializers.SerializerMethodField()
+
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
 
     def to_json_array(self, obt_list):
         serialized_hardware = []
@@ -215,6 +242,13 @@ class HardwareIOSerializer(serializers.ModelSerializer):
 
 class DataTransformerConstantsSerializer(serializers.ModelSerializer):
     data_transformer = serializers.PrimaryKeyRelatedField(read_only=True)
+    model = serializers.SerializerMethodField()
+
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
 
     class Meta:
         model = DataTransformerConstants
@@ -230,6 +264,14 @@ class DataTransformerTreeSerializer(serializers.ModelSerializer):
 
 
     children = serializers.SerializerMethodField(source='get_children')
+    model = serializers.SerializerMethodField()
+
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
+
     class Meta:
         model=DataTransformer
         fields = '__all__'  # add here rest of the fields from model
@@ -249,7 +291,15 @@ class AccessorySerializer(serializers.ModelSerializer):
     # channels = ChannelSerializer(source='channel_set', many=True)
     calibration = CalibrationSerializer(source='calibration_set', many=True, read_only=False)
     datatransformer = DataTransformerTreeSerializer(read_only=True)
+    model = serializers.SerializerMethodField()
+
+    def get_model(self, instance):
+        try:
+            return instance.__class__.__name__
+        except:
+            return None
+
     class Meta:
         model = Accessory
         fields = ['id', 'category', 'type', 'display_name', 'aid',
-                  'calibration', 'channels','datatransformer']
\ No newline at end of file
+                  'calibration', 'channels','datatransformer','model']
\ No newline at end of file
